@@ -12,10 +12,10 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-ecs-service-extensions",
-    "0.0.2",
+    "@aws-cdk-containers/ecs-service-extensions",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-ecs-service-extensions@0.0.2.jsii.tgz",
+    "ecs-service-extensions@2.0.0.jsii.tgz",
 )
 
 __all__ = [
